# Python approximation to Hilbert spaces and Quantum Mechanics

Numeric Lebesgue _L²_ space implementation over ℝ - including Fourier basis - or ℂ.

Quantum systems:

  * Quasi-free particle in one dimension

See the demo-tests in the notebooks folder.
